To summarise one of the daily outputs of the following fonctions from BEE package : bee.calc.metrics_point() ; bee.calc.metrics_morpho() ; bee.calc.escape() ; bee.data.merge(). Metrics values can be summarised per extreme event or over a sliding time window.
BEE.data.summarise(
data = data,
variable = variable,
summarise_by = "extreme_event"
): The dataset containing the column you want to process (e.g. the ouput of BEE.data.merge(), as a list of data frame).
: The name of the column for which you want to compute mean, median etc. over a time window.
: Takes the following options:
"extreme_event" for each metric, the following will be computed for each extreme event: mean, median, variance or sd, minimum and maximum, sum, and the dates of the maximum and minimum values.
a numeric value indicating the time step for which you want to compute the mean, median, etc.
A list of dataframes, with one dataframe per pixel, with the dates in the rows and the values summarised.
In addition to the mean value, the function provides the median, standard deviation, minimum and maximum values, sum, date of minimum and maximum values (within the time window), and date of minimum value (also within the time window).
# TO BE ADDED